==> qxcommon-1.0.02-sources.jar: cn/com/startai/qxcommon/QXCommon.java <==
package cn.com.startai.qxcommon;


import android.app.Application;
import android.util.Log;

import org.xutils.x;


import cn.com.startai.common.CommonSDKInterface;
import cn.com.startai.common.channel.ICallListener;
import cn.com.startai.common.utils.CAppUtils;
import cn.com.startai.common.utils.CLog;
import cn.com.startai.qxcommon.db.QXDBManager;
import cn.com.startai.qxcommon.event.QXEventDispatcher;
import cn.com.startai.qxcommon.global.ParamManager;
import cn.com.startai.qxcommon.link.BaseData;
import cn.com.startai.qxcommon.link.Channel;
import cn.com.startai.qxcommon.link.IOutput;
import cn.com.startai.qxcommon.link.mqtt.QXMqttManager;
import cn.com.startai.qxcommon.utils.QXSpController;
import cn.com.startai.qxcommon.utils.filter.IMessageFilter;
import cn.com.startai.qxcommon.utils.filter.QXMessageFilter;

/**
 * Created by Robin on 2019/5/12.
 * 419109715@qq.com 彬影
 */
public class QXCommon implements IOutput {

    public static String TAG = "QX";


    private QXCommon() {
    }

    public static QXCommon getInstance() {
        return SingleTonHoulder.singleTonInstance;
    }


    private static class SingleTonHoulder {
        private static final QXCommon singleTonInstance = new QXCommon();
    }

    private Application app;
    private IMessageFilter messageFilter;

    private boolean isInit() {
        return app != null;
    }

    public Application getApp() {
        return app;
    }

    public void init(Application app, QXCommonInitParam initParam) {
        if (isInit()) {
            Log.e(TAG, "no need repeat init ");
            return;
        }

        long t = System.currentTimeMillis();
        if (initParam == null || initParam.getAppid() == 0) {
            Log.e(TAG, "QXCommon init failed 'qxInitParam' is empty or 'appid' is empty ");
            return;
        }

        this.app = app;
        messageFilter = new QXMessageFilter();
        x.Ext.init(app);

        CommonSDKInterface.getInstance().init(app);
        QXSpController.getInstance().init();
        TAG = CAppUtils.getAppName();
        CommonSDKInterface.TAG = TAG;

        ParamManager.getInstance().init(initParam.getAppid());
        CLog.d(TAG, "init use time 1 = " + (System.currentTimeMillis() - t));
        initMqtt();

        CLog.d(TAG, "init use time 2 = " + (System.currentTimeMillis() - t));
    }


    public void release() {
        CLog.d(TAG, "QXCommon release");
        releaseMqtt();
        QXDBManager.getInstance().release();
        QXSpController.getInstance().release();
        CommonSDKInterface.getInstance().release();
        app = null;
        messageFilter = null;
        ParamManager.getInstance().release();
    }


    private void initMqtt() {
        QXMqttManager.getInstance().init();
    }

    private void releaseMqtt() {
        QXMqttManager.getInstance().release();
    }

    @Override
    public void doSend(final BaseData baseData, final ICallListener listener) {


        if (baseData == null) {
            CLog.e(TAG, "baseData = null or baseData.data = null");
            return;
        }

        if (baseData.getChannel() == Channel.MQTT) {
            doSendMqtt(baseData, listener);
            return;
        }

        if (baseData.getChannel() == Channel.UDP) {
            doSendUdp(baseData, listener);
            return;
        }
        if (baseData.getChannel() == Channel.BLE) {
            doSendBle(baseData, listener);
            return;
        }

        if (baseData.getChannel() == Channel.ANY) {
            doSendUdp(baseData, new ICallListener() {
                @Override
                public void onSuccess() {
                    listener.onSuccess();
                }

                @Override
                public void onFailed(int i) {
                    doSendMqtt(baseData, listener);
                }
            });
        }

    }

    @Override
    public void doSendMqtt(BaseData qxMqttData, ICallListener listener) {
        if (messageFilter == null || !messageFilter.doSendFilter(qxMqttData)) {
            QXMqttManager.getInstance().publish(qxMqttData.getTopic(), qxMqttData.getData(), listener);
        } else {
            listener.onSuccess();
        }
    }

    @Override
    public void doSendUdp(BaseData qxudpData, ICallListener listener) {
        if (messageFilter == null || !messageFilter.doSendFilter(qxudpData)) {
        } else {
            listener.onSuccess();
        }
    }

    @Override
    public void doSendBle(BaseData qxbleData, ICallListener listener) {
        if (messageFilter == null || !messageFilter.doSendFilter(qxbleData)) {
        } else {
            listener.onSuccess();
        }
    }


}

==> qxcommon-1.0.06-sources.jar: cn/com/startai/qxcommon/QXCommon.java <==
package cn.com.startai.qxcommon;


import android.app.Application;
import android.util.Log;

import org.xutils.x;


import cn.com.startai.common.CommonSDKInterface;
import cn.com.startai.common.channel.ICallListener;
import cn.com.startai.common.utils.CAppUtils;
import cn.com.startai.common.utils.CLog;
import cn.com.startai.qxcommon.db.QXDBManager;
import cn.com.startai.qxcommon.global.ParamManager;
import cn.com.startai.qxcommon.link.BaseData;
import cn.com.startai.qxcommon.link.Channel;
import cn.com.startai.qxcommon.link.IOutput;
import cn.com.startai.qxcommon.link.mqtt.QXMqttManager;
import cn.com.startai.qxcommon.utils.QXSpController;
import cn.com.startai.qxcommon.utils.filter.IMessageFilter;
import cn.com.startai.qxcommon.utils.filter.QXMessageFilter;

/**
 * Created by Robin on 2019/5/12.
 * 419109715@qq.com 彬影
 */
public class QXCommon implements IOutput {

    public static String TAG;


    private QXCommon() {
    }

    public static QXCommon getInstance() {
        return SingleTonHoulder.singleTonInstance;
    }


    private static class SingleTonHoulder {
        private static final QXCommon singleTonInstance = new QXCommon();
    }

    private Application app;
    private IMessageFilter messageFilter;

    private boolean isInit() {
        return app != null;
    }

    public Application getApp() {
        return app;
    }

    public void init(Application app, QXCommonInitParam initParam) {
        if (isInit()) {
            Log.e(TAG, "no need repeat init ");
            return;
        }

        long t = System.currentTimeMillis();
        if (initParam == null || initParam.getAppid() == 0) {
            Log.e(TAG, "QXCommon init failed 'qxInitParam' is empty or 'appid' is empty ");
            return;
        }

        this.app = app;
        messageFilter = new QXMessageFilter();
        x.Ext.init(app);

        CommonSDKInterface.getInstance().init(app);
        QXSpController.getInstance().init();
        if (TAG == null) {
            TAG = CAppUtils.getAppName();
        }
        CommonSDKInterface.TAG = TAG;

        ParamManager.getInstance().init(initParam.getAppid());
        CLog.d(TAG, "init use time 1 = " + (System.currentTimeMillis() - t));
        initMqtt();

        CLog.d(TAG, "init use time 2 = " + (System.currentTimeMillis() - t));
    }


    public void release() {
        CLog.d(TAG, "QXCommon release");
        releaseMqtt();
        QXDBManager.getInstance().release();
        QXSpController.getInstance().release();
        CommonSDKInterface.getInstance().release();
        app = null;
        messageFilter = null;
        ParamManager.getInstance().release();
    }


    private void initMqtt() {
        QXMqttManager.getInstance().init();
    }

    private void releaseMqtt() {
        QXMqttManager.getInstance().release();
    }

    @Override
    public void doSend(final BaseData baseData, final ICallListener listener) {


        if (baseData == null) {
            CLog.e(TAG, "baseData = null or baseData.data = null");
            return;
        }

        if (baseData.getChannel() == Channel.MQTT) {
            doSendMqtt(baseData, listener);
            return;
        }

        if (baseData.getChannel() == Channel.UDP) {
            doSendUdp(baseData, listener);
            return;
        }
        if (baseData.getChannel() == Channel.BLE) {
            doSendBle(baseData, listener);
            return;
        }

        if (baseData.getChannel() == Channel.ANY) {
            doSendUdp(baseData, new ICallListener() {
                @Override
                public void onSuccess() {
                    listener.onSuccess();
                }

                @Override
                public void onFailed(int i) {
                    doSendMqtt(baseData, listener);
                }
            });
        }

    }

    @Override
    public void doSendMqtt(BaseData qxMqttData, ICallListener listener) {
        if (messageFilter == null || !messageFilter.doSendFilter(qxMqttData)) {
            QXMqttManager.getInstance().publish(qxMqttData.getTopic(), qxMqttData.getData(), listener);
        } else {
            listener.onSuccess();
        }
    }

    @Override
    public void doSendUdp(BaseData qxudpData, ICallListener listener) {
        if (messageFilter == null || !messageFilter.doSendFilter(qxudpData)) {
        } else {
            listener.onSuccess();
        }
    }

    @Override
    public void doSendBle(BaseData qxbleData, ICallListener listener) {
        if (messageFilter == null || !messageFilter.doSendFilter(qxbleData)) {
        } else {
            listener.onSuccess();
        }
    }


}
